@@ -22,7 +22,7 @@ mag_2_tibb <- function(gdp) {
   gdp %>%
     magclass::as.data.frame() %>%
     tibble::as_tibble() %>%
-    dplyr::select(-.data$Cell) %>%
+    dplyr::select(-"Cell") %>%
     dplyr::rename("iso3c" = "Region", "year" = "Year", "value" = "Value") %>%
     dplyr::mutate(year = as.integer(as.character(.data$year)))
-}
\ No newline at end of file
+}
